from django.contrib import admin
from django.utils.translation import ugettext as _
import time
from amxbans.models import Ban, Admin, AdminInfo, Server, ServerAdmin

class BanAdmin(admin.ModelAdmin):
	actions = ['unban',]
	list_display = ('player_nick', 'admin_nick', 'get_length', 'get_creation_date', 'is_active')
	list_filter = ('admin_nick',)
	search_fields = ('player_ip', 'player_nick', 'player_id')
	readonly_fields = ('admin_ip', 'admin_id', 'admin_nick', 'ban_created', 'server_ip', 'server_name', 'ban_kicks', 'expired', 'imported')
	ordering = ('-ban_created',)

	def unban(self, request, queryset):
		queryset.update(expired=1)
		self.message_user(request, _('Unbanned.'))

admin.site.register(Ban, BanAdmin)

class AdminInfoInline(admin.StackedInline):
	model = AdminInfo

class AdminAdmin(admin.ModelAdmin):
	list_display = ('nickname', 'username', 'access', 'flags')
	exclude = ('expired', 'created')
	inlines = [AdminInfoInline,]

	def save_model(self, request, obj, form, change):
		if not obj.pk:
			obj.created = int(time.time())
		obj.save()
admin.site.register(Admin, AdminAdmin)

class ServerAdminAdmin(admin.TabularInline):
	model = ServerAdmin
	fields = ('admin', 'custom_flags', 'use_static_bantime')
	#readonly_fields = ('admin',)
	extra = 1

class ServerAdmin(admin.ModelAdmin):
	inlines = [ServerAdminAdmin,]
	list_display = ('hostname', 'address', 'amxban_version', 'get_last_seen')
	exclude = ('timestamp', 'reasons', 'timezone_fixx')
	readonly_fields = ('amxban_version',)
admin.site.register(Server, ServerAdmin)
