from django.contrib import messages
from django.contrib.auth.decorators import login_required, permission_required
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response, get_object_or_404
from django.template.context import RequestContext
from django.utils.translation import ugettext as _
from amxbans.models import Ban, Admin, Server

__author__ = 'aither'

def banlist(request):
	return render_to_response('amxbans/banlist.html', {
		'bans': Ban.objects.filter(ban_length__gt=-1).order_by('-pk'),
	    'ip': request.META['REMOTE_ADDR'],
	    'banned': True if Ban.objects.filter(player_ip=request.META['REMOTE_ADDR'], expired=0).count() > 0 else False,
	}, context_instance=RequestContext(request))

def admins(request):
	return render_to_response('amxbans/admins.html', {
		'admins': Admin.objects.filter(access__contains='c').order_by('admininfo__role', 'nickname'),
		'servers': Server.objects.select_related().all(),
	}, context_instance=RequestContext(request))


def ban(request, banid):
	return render_to_response('amxbans/ban.html', {'ban': get_object_or_404(Ban, pk=banid)},
	                          context_instance=RequestContext(request))

@login_required
@permission_required("amxbans.change_ban")
def unban(request, banid):
	ban = get_object_or_404(Ban, pk=banid)

	ban.expired = 1
	ban.save()

	messages.add_message(request, messages.INFO, _('Player %s has been successfuly unbanned' % ban.player_nick))

	return HttpResponseRedirect( reverse('amxbans.views.ban', kwargs={'banid': ban.pk,}) )